==> autoboto-0.0.3.tar.gz: autoboto-0.0.3/autoboto/services/mediatailor/client.py <==
import datetime
import typing
import boto3
import autoboto
from . import shapes


class Client:
    def __init__(self, *args, **kwargs):
        self._boto_client = boto3.client("mediatailor", *args, **kwargs)

    def delete_playback_configuration(
        self,
        _request: shapes.DeletePlaybackConfigurationRequest = None,
        *,
        name: str,
    ) -> shapes.DeletePlaybackConfigurationResponse:
        """
        Deletes the configuration for the specified name.
        """
        if _request is None:
            _params = {}
            if name is not autoboto.ShapeBase._NOT_SET:
                _params['name'] = name
            _request = shapes.DeletePlaybackConfigurationRequest(**_params)
        response = self._boto_client.delete_playback_configuration(
            **_request.to_boto_dict()
        )

        return shapes.DeletePlaybackConfigurationResponse.from_boto_dict(
            response
        )

    def get_playback_configuration(
        self,
        _request: shapes.GetPlaybackConfigurationRequest = None,
        *,
        name: str,
    ) -> shapes.GetPlaybackConfigurationResponse:
        """
        Returns the configuration for the specified name.
        """
        if _request is None:
            _params = {}
            if name is not autoboto.ShapeBase._NOT_SET:
                _params['name'] = name
            _request = shapes.GetPlaybackConfigurationRequest(**_params)
        response = self._boto_client.get_playback_configuration(
            **_request.to_boto_dict()
        )

        return shapes.GetPlaybackConfigurationResponse.from_boto_dict(response)

    def list_playback_configurations(
        self,
        _request: shapes.ListPlaybackConfigurationsRequest = None,
        *,
        max_results: int = autoboto.ShapeBase._NOT_SET,
        next_token: str = autoboto.ShapeBase._NOT_SET,
    ) -> shapes.ListPlaybackConfigurationsResponse:
        """
        Returns a list of the configurations defined in AWS Elemental MediaTailor. You
        can specify a max number of configurations to return at a time. The default max
        is 50. Results are returned in pagefuls. If AWS Elemental MediaTailor has more
        configurations than the specified max, it provides parameters in the response
        that you can use to retrieve the next pageful.
        """
        if _request is None:
            _params = {}
            if max_results is not autoboto.ShapeBase._NOT_SET:
                _params['max_results'] = max_results
            if next_token is not autoboto.ShapeBase._NOT_SET:
                _params['next_token'] = next_token
            _request = shapes.ListPlaybackConfigurationsRequest(**_params)
        response = self._boto_client.list_playback_configurations(
            **_request.to_boto_dict()
        )

        return shapes.ListPlaybackConfigurationsResponse.from_boto_dict(
            response
        )

    def put_playback_configuration(
        self,
        _request: shapes.PutPlaybackConfigurationRequest = None,
        *,
        ad_decision_server_url: str = autoboto.ShapeBase._NOT_SET,
        cdn_configuration: shapes.CdnConfiguration = autoboto.ShapeBase.
        _NOT_SET,
        name: str = autoboto.ShapeBase._NOT_SET,
        slate_ad_url: str = autoboto.ShapeBase._NOT_SET,
        video_content_source_url: str = autoboto.ShapeBase._NOT_SET,
    ) -> shapes.PutPlaybackConfigurationResponse:
        """
        Adds a new configuration to AWS Elemental MediaTailor.
        """
        if _request is None:
            _params = {}
            if ad_decision_server_url is not autoboto.ShapeBase._NOT_SET:
                _params['ad_decision_server_url'] = ad_decision_server_url
            if cdn_configuration is not autoboto.ShapeBase._NOT_SET:
                _params['cdn_configuration'] = cdn_configuration
            if name is not autoboto.ShapeBase._NOT_SET:
                _params['name'] = name
            if slate_ad_url is not autoboto.ShapeBase._NOT_SET:
                _params['slate_ad_url'] = slate_ad_url
            if video_content_source_url is not autoboto.ShapeBase._NOT_SET:
                _params['video_content_source_url'] = video_content_source_url
            _request = shapes.PutPlaybackConfigurationRequest(**_params)
        response = self._boto_client.put_playback_configuration(
            **_request.to_boto_dict()
        )

        return shapes.PutPlaybackConfigurationResponse.from_boto_dict(response)

==> autoboto-0.2.2.tar.gz: autoboto-0.2.2/autoboto/services/mediatailor/client.py <==
import datetime
import typing
import boto3
from autoboto import ShapeBase, OutputShapeBase
from . import shapes


class Client:
    def __init__(self, *args, **kwargs):
        self._boto_client = boto3.client("mediatailor", *args, **kwargs)

    def delete_playback_configuration(
        self,
        _request: shapes.DeletePlaybackConfigurationRequest = None,
        *,
        name: str,
    ) -> shapes.DeletePlaybackConfigurationResponse:
        """
        Deletes the configuration for the specified name.
        """
        if _request is None:
            _params = {}
            if name is not ShapeBase.NOT_SET:
                _params['name'] = name
            _request = shapes.DeletePlaybackConfigurationRequest(**_params)
        response = self._boto_client.delete_playback_configuration(
            **_request.to_boto_dict()
        )

        return shapes.DeletePlaybackConfigurationResponse.from_boto_dict(
            response
        )

    def get_playback_configuration(
        self,
        _request: shapes.GetPlaybackConfigurationRequest = None,
        *,
        name: str,
    ) -> shapes.GetPlaybackConfigurationResponse:
        """
        Returns the configuration for the specified name.
        """
        if _request is None:
            _params = {}
            if name is not ShapeBase.NOT_SET:
                _params['name'] = name
            _request = shapes.GetPlaybackConfigurationRequest(**_params)
        response = self._boto_client.get_playback_configuration(
            **_request.to_boto_dict()
        )

        return shapes.GetPlaybackConfigurationResponse.from_boto_dict(response)

    def list_playback_configurations(
        self,
        _request: shapes.ListPlaybackConfigurationsRequest = None,
        *,
        max_results: int = ShapeBase.NOT_SET,
        next_token: str = ShapeBase.NOT_SET,
    ) -> shapes.ListPlaybackConfigurationsResponse:
        """
        Returns a list of the configurations defined in AWS Elemental MediaTailor. You
        can specify a max number of configurations to return at a time. The default max
        is 50. Results are returned in pagefuls. If AWS Elemental MediaTailor has more
        configurations than the specified max, it provides parameters in the response
        that you can use to retrieve the next pageful.
        """
        if _request is None:
            _params = {}
            if max_results is not ShapeBase.NOT_SET:
                _params['max_results'] = max_results
            if next_token is not ShapeBase.NOT_SET:
                _params['next_token'] = next_token
            _request = shapes.ListPlaybackConfigurationsRequest(**_params)
        response = self._boto_client.list_playback_configurations(
            **_request.to_boto_dict()
        )

        return shapes.ListPlaybackConfigurationsResponse.from_boto_dict(
            response
        )

    def put_playback_configuration(
        self,
        _request: shapes.PutPlaybackConfigurationRequest = None,
        *,
        ad_decision_server_url: str = ShapeBase.NOT_SET,
        cdn_configuration: shapes.CdnConfiguration = ShapeBase.NOT_SET,
        name: str = ShapeBase.NOT_SET,
        slate_ad_url: str = ShapeBase.NOT_SET,
        video_content_source_url: str = ShapeBase.NOT_SET,
    ) -> shapes.PutPlaybackConfigurationResponse:
        """
        Adds a new configuration to AWS Elemental MediaTailor.
        """
        if _request is None:
            _params = {}
            if ad_decision_server_url is not ShapeBase.NOT_SET:
                _params['ad_decision_server_url'] = ad_decision_server_url
            if cdn_configuration is not ShapeBase.NOT_SET:
                _params['cdn_configuration'] = cdn_configuration
            if name is not ShapeBase.NOT_SET:
                _params['name'] = name
            if slate_ad_url is not ShapeBase.NOT_SET:
                _params['slate_ad_url'] = slate_ad_url
            if video_content_source_url is not ShapeBase.NOT_SET:
                _params['video_content_source_url'] = video_content_source_url
            _request = shapes.PutPlaybackConfigurationRequest(**_params)
        response = self._boto_client.put_playback_configuration(
            **_request.to_boto_dict()
        )

        return shapes.PutPlaybackConfigurationResponse.from_boto_dict(response)
